@@ -87,7 +87,7 @@ def test_instruments():
         host=get_platform_dispatcher(),
         instrument="mock",
     )
-    assert disp.get_instruments_list() == ['isgri', 'jemx', 'polar', 'spi_acs']
+    assert disp.get_instruments_list() == ['magic', 'isgri', 'jemx', 'polar', 'antares', 'spi_acs']
 
 
 def test_instrument_description_not_null():
@@ -215,7 +215,7 @@ def test_token_expired(dispatcher_live_fixture):
 
         raise RuntimeError('did not raise Unauthorized for expired token')
     except Unauthorized as e:
-        assert e.message == "RequestNotAuthorized():the token provided is expired, please try to logout and login again"
+        assert e.message == "RequestNotAuthorized():The token provided is expired, please try to logout and login again. If already logged out, please clean the cookies, and resubmit you request."
 
 
 @pytest.mark.slow
